#
# spec file for package sshfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sshfs
Version:        2.9
Release:        lp150.1.3
Summary:        Filesystem client based on SSH file transfer protocol
License:        GPL-2.0+
Group:          System/Filesystems
Url:            https://github.com/libfuse/sshfs
Source:         https://github.com/libfuse/sshfs/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  fuse-devel
BuildRequires:  glib2-devel
Requires:       fuse
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SSHFS is a filesystem client based on the SSH File Transfer Protocol.
Since most SSH servers already support this protocol it is very easy to
set up: i.e. on the server side there's nothing to do.	On the client
side mounting the filesystem is as easy as logging into the server with
openssh (ssh).

%prep
%setup -q

%build
%{?suse_update_config:%{suse_update_config -f}}
autoreconf -fi
%configure --disable-sshnodelay
make %{?_smp_mflags} V=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%{_mandir}/*/*
%{_bindir}/*

%changelog
* Mon Jul 24 2017 mimi.vx@gmail.com
- update to 2.9
  * various bugfixes
* Sun May 28 2017 toms@opensuse.org
- Spec file:
  Correct URL from Sourceforge to GitHub (the SF URL is redirected
  to GH anyway)
* Tue Oct 18 2016 mimi.vx@gmail.com
- update to 2.8
- Added support for the "fsync" extension
* Thu Mar 17 2016 mimi.vx@gmail.com
- update to 2.7
- spec-cleaned spec file
  * Added -o cache_max_size=N option to let users tune the maximum size of the cache
  in number of entries.
  * Added -o cache_clean_interval=N and -o cache_min_clean_interval=N options to
  let users tune the cleaning behavior of the cache.
* Fri Oct  3 2014 dsterba@suse.cz
- update to 2.5
  * Add -o disable_hardlink option (debian bug #670926).
  * Optimize readdir by sending multiple requests in parallel.  Add -o
    sync_readdir to restore old behavior.
  * Map SSH2_FX_FAILURE to ENOTEMPTY for rmdir.
  * When checking root directory use LSTAT not STAT.  This prevents I/O error
    being returned after a successful mount if a symlink is mounted.
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Fri Mar 16 2012 tabraham@novell.com
- update to 2.4
  * Add "-oworkaround=fstat" for SFTP servers which don't support
    the FSTAT message.  Patch by: Percy Jahn
  * Remove "-oPreferredAuthentications" from ssh options if the
    "password_stdin" option is used.  Reported by E. Kuemmerle
  * Fix double free if reconnection races with request sending.
    Patch by E. Kuemmerle
  * Submit max 32k reads and writes to the sftp server.  Also don't
    limit the kernel to 64k reads and writes, rather split into 32k
    sized chunks and send them to the server all at once.  This is
    more efficient and less demanding from the server.  Reported by
    Ludovic Courtès.  Fix suggested by Niels Möller
  * Make chown respect the UID mapping policy.  Reported and tested
    by Vivenzio Pagliari
  * Add -o idmap=file, -o uidmap=FILE, -o gidmap=FILE. These options
    allow you to create a pair of local files, similar to /etc/passwd or
    /etc/group files from the remote server, and use those to remap all
    the given UIDs/GIDs.
  * Add -o slave. This option routes the sftp communication over stdin
    and stdout, bypassing SSH and network.
  * Make sure idmap files aren't writable by others otherwise, other
    local users could change the mapping, and gain access to things
    they shouldn't.  Patch by Mike Kelly
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Oct 11 2011 tabraham@novell.com
- updated to 2.3
  * Add hard link operation
  * Fix possible deadlock on reconnection
  * Fix cleanup when ssh connection is terminated to prevent
    sshfs hanging when the server is rebooted, for example
  * Set FD_CLOEXEC on fuse device to prevent deadlocks
  * Check mountpoint and fuse options before starting an ssh
    session
  * Allow mounting a single non-directory from the server
  * Add option 'delay_connect'
  * Print usage information and version to stdout, not stderr
* Tue Mar 22 2011 coolo@novell.com
- licenses package is about to die
* Wed Oct 29 2008 mszeredi@suse.de
- updated to version 2.2
  * Handle numerical IPv6 addresses enclosed in square brackets.
  * Fix error if username contains a comma character
* Fri Jul 25 2008 mszeredi@suse.de
- updated to version 2.1
  * Support password authentication with pam_mount
  * Support atomic renames if server is OpenSSH 4.9 or later
  * Support getting disk usage if server is OpenSSH 5.1 or later
  * Add man page
  * Improved ssh option support
  * Improved support for specifying a special ssh command
  * Fix bug that could cause corruption with append mode writes
  * Allow specifying an ssh config file
* Mon Dec 17 2007 mszeredi@suse.de
- updated to version 1.9
  * Fix crash when writing large files on SMP
  * Fill in st_ctime attribute
  * Add mount subtype support
  * Small optimizations
* Fri Aug 10 2007 bk@suse.de
- Add "Requires: fuse" to ensure that fuse is present (285101#c29)
* Thu May 17 2007 mszeredi@suse.de
- updated to version 1.8
  * Fix rare crashes due to uninitialized threading in glib
  * Fix memory leak in open
  * Fix crash when sem_wait() is interrupted (e.g. by gdb)
  * Fix caching when renaming a directory
  * Work around crash of sftp-server when its input buffer is full
  * Add option to work around performance problem with old ssh
    servers
  * Fix bug in follow_symlinks option
- Don't build sshnodelay.so, which is not needed any more with
  current ssh clients
* Thu Oct 12 2006 tiwai@suse.de
- update to version 1.7:
  * Add option 'follow_symlinks' to resolve symlinks on the server
  * Fix for sftp with login shell printing a banner
  * Check remote directory for existence before mounting
* Wed May 17 2006 schwab@suse.de
- Don't strip binaries.
* Tue May 16 2006 tiwai@suse.de
- updated to version 1.6
  * Fix segfault if remote host is down and reconnection is
    enabled
  * Fix bug in symlink transformation
  * Add workaround for broken truncate on old sftp servers
  * Memory copy optimizations
* Mon Feb 20 2006 cthiel@suse.de
- update to version 1.5
  * Add workaround (enabled by default) for ssh clients not setting
    TCP_NODELAY on the network connection.  Currently this is all known
    versions of openssh.  This may improve download speed in some
    circumstances
  * Use TCP_NODELAY socket option for direct connection.  This may improve
    download speed in some circumstances
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 15 2006 cthiel@suse.de
- update to version 1.4
* Tue Nov 22 2005 msvec@suse.cz
- update to version 1.3
* Tue Sep 20 2005 cthiel@suse.de
- update to version 1.2
* Wed May 25 2005 tiwai@suse.de
- initial version: 1.1
